@@ -426,9 +426,9 @@ static int show_fkey(int key)
     
     if( cm->fkeyhelp[fkey].textname ) {
 	 int slent = strlen(cm->fkeyhelp[fkey].textname);
-         if (slent>4 &&
+         if (slent<4 ||
 	     (strcmp(cm->fkeyhelp[fkey].textname+slent-4,".txt")
-         || strcmp(cm->fkeyhelp[fkey].textname+slent-4,".msg"))) {
+         && strcmp(cm->fkeyhelp[fkey].textname+slent-4,".msg"))) {
 	     return fkey;
 	 }
     }
